def distance_of_time_in_words(from_time, to_time = 0)
   from_time = from_time.to_time if from_time.respond_to?(:to_time)
   to_time = to_time.to_time if to_time.respond_to?(:to_time)
   from_time, to_time = to_time, from_time if from_time > to_time
   distance_in_minutes = ((to_time - from_time)/60.0).round
   distance_in_seconds = (to_time - from_time).round

  case distance_in_minutes
  when 0..1 
    case distance_in_seconds
      when 0..4   then "less than 5 seconds"
      when 5..9   then "less than 10 seconds"
      when 10..19 then "less than 20 seconds"
      when 20..39 then "half a minute"
      when 40..59 then "less than a minute"
      else             "1 minute"
    end
  when 2...45           then "#{distance_in_minutes} minutes"
  when 45...90          then "about 1 hour"
  # 90 mins up to 24 hours
  when 90...1440        then "about #{(distance_in_minutes.to_f / 60.0).round} hours"
  # 24 hours up to 42 hours
  when 1440...2520      then "1 day"
  # 42 hours up to 30 days
  when 2520...43200     then "#{(distance_in_minutes.to_f / 1440.0).round} days"
  # 30 days up to 60 days
  when 43200...86400    then "about 1 month"
  # 60 days up to 365 days
  when 86400...525600   then "#{(distance_in_minutes.to_f / 43200.0).round} months"
  else
    if from_time.acts_like?(:time) && to_time.acts_like?(:time)
      fyear = from_time.year
      fyear += 1 if from_time.month >= 3
      tyear = to_time.year
      tyear -= 1 if to_time.month < 3
      leap_years = (fyear > tyear) ? 0 : (fyear..tyear).count{|x| Date.leap?(x)}
      minute_offset_for_leap_year = leap_years * 1440
      # Discount the leap year days when calculating year distance.
      # e.g. if there are 20 leap year days between 2 dates having the same day
      # and month then the based on 365 days calculation
      # the distance in years will come out to over 80 years when in written
      # english it would read better as about 80 years.
      minutes_with_offset = distance_in_minutes - minute_offset_for_leap_year
    else
      minutes_with_offset = distance_in_minutes
    end
    remainder                   = (minutes_with_offset % 525600)
    distance_in_years           = (minutes_with_offset / 525600)
    if remainder < 131400
      "about #{distance_in_years} year"
    elsif remainder < 394200
      "over #{distance_in_years} year"
    else
      "almost #{distance_in_years + 1} years"
    end
  end
end